Class: AlwaysApplySampling

Inherits:
Object
  • Object
show all
Defined in:
lib/wingify/models/settings/internal_event_sampling_settings_model.rb

Overview

Controls whether sampling is enforced before sending an event. When server is false (the default), usage-stats and sampled debug events bypass sampling and are always sent.

Instance Method Summary collapse

Constructor Details

#initialize(data) ⇒ AlwaysApplySampling

Returns a new instance of AlwaysApplySampling.



53
54
55
56
# File 'lib/wingify/models/settings/internal_event_sampling_settings_model.rb', line 53

def initialize(data)
  data ||= {}
  @server = data['server']
end

Instance Method Details

#get_serverBoolean?

Returns Whether sampling must be applied on the server runtime.

Returns:

  • (Boolean, nil)

    Whether sampling must be applied on the server runtime



59
60
61
# File 'lib/wingify/models/settings/internal_event_sampling_settings_model.rb', line 59

def get_server
  @server
end