Class: GetFlagResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/wingify/models/user/get_flag_response.rb

Overview

Copyright 2024-2026 Wingify Software Pvt. Ltd.

Licensed under the Apache License, Version 2.0 (the “License”); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(is_enabled, variables = [], uuid = nil, session_id = nil) ⇒ GetFlagResponse

Returns a new instance of GetFlagResponse.



18
19
20
21
22
23
# File 'lib/wingify/models/user/get_flag_response.rb', line 18

def initialize(is_enabled, variables = [], uuid = nil, session_id = nil)
  @is_enabled = is_enabled
  @variables = variables
  @uuid = uuid
  @session_id = session_id
end

Instance Attribute Details

#get_session_idObject (readonly)

Define method for get_session_id



47
48
49
# File 'lib/wingify/models/user/get_flag_response.rb', line 47

def get_session_id
  @get_session_id
end

#get_uuidObject (readonly)

Define method for get_uuid



42
43
44
# File 'lib/wingify/models/user/get_flag_response.rb', line 42

def get_uuid
  @get_uuid
end

#get_variable(key, default_value = nil) ⇒ Object (readonly)

Define method for get_variable



36
37
38
# File 'lib/wingify/models/user/get_flag_response.rb', line 36

def get_variable
  @get_variable
end

#get_variablesObject (readonly)

Define method for get_variables



31
32
33
# File 'lib/wingify/models/user/get_flag_response.rb', line 31

def get_variables
  @get_variables
end

#is_enabledObject (readonly)

Define method for is_enabled



26
27
28
# File 'lib/wingify/models/user/get_flag_response.rb', line 26

def is_enabled
  @is_enabled
end