Module: VWO

Defined in:
lib/vwo.rb

Class Method Summary collapse

Class Method Details

.get_uuid(user_id, account_id) ⇒ Object



31
32
33
# File 'lib/vwo.rb', line 31

def self.get_uuid(user_id, )
  Wingify.get_uuid(user_id, )
end

.init(options) ⇒ Object

Backward compatible VWO facade It intercepts the init call, forces the is_via_vwo flag, and forwards to Wingify core.



26
27
28
29
# File 'lib/vwo.rb', line 26

def self.init(options)
  options[:is_via_vwo] = true
  Wingify.init(options)
end

.new(options) ⇒ Object

Keep VWO.new backward compatible for any customers manually instantiating it, although standard docs recommend VWO.init



37
38
39
# File 'lib/vwo.rb', line 37

def self.new(options)
  init(options)
end