Class: VWOOptionsModel
- Inherits:
-
Object
- Object
- VWOOptionsModel
- Defined in:
- lib/wingify/models/vwo_options_model.rb
Overview
Copyright 2024-2026 Wingify Software Pvt. Ltd.
Licensed under the Apache License, Version 2.0 (the “License”); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Instance Attribute Summary collapse
-
#_vwo_meta ⇒ Object
Returns the value of attribute _vwo_meta.
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#gateway_service ⇒ Object
Returns the value of attribute gateway_service.
-
#integrations ⇒ Object
Returns the value of attribute integrations.
-
#is_development_mode ⇒ Object
Returns the value of attribute is_development_mode.
-
#is_usage_stats_disabled ⇒ Object
Returns the value of attribute is_usage_stats_disabled.
-
#logger ⇒ Object
Returns the value of attribute logger.
-
#network ⇒ Object
Returns the value of attribute network.
-
#poll_interval ⇒ Object
Returns the value of attribute poll_interval.
-
#proxy_url ⇒ Object
Returns the value of attribute proxy_url.
-
#retry_config ⇒ Object
Returns the value of attribute retry_config.
-
#sdk_key ⇒ Object
Returns the value of attribute sdk_key.
-
#segmentation ⇒ Object
Returns the value of attribute segmentation.
-
#settings ⇒ Object
Returns the value of attribute settings.
-
#should_wait_for_tracking_calls ⇒ Object
Returns the value of attribute should_wait_for_tracking_calls.
-
#storage ⇒ Object
Returns the value of attribute storage.
-
#vwo_builder ⇒ Object
Returns the value of attribute vwo_builder.
Instance Method Summary collapse
- #get_account_id ⇒ Object
- #get_gateway_service ⇒ Object
- #get_integrations ⇒ Object
- #get_is_development_mode ⇒ Object
- #get_is_usage_stats_disabled ⇒ Object
- #get_logger ⇒ Object
- #get_network ⇒ Object
- #get_poll_interval ⇒ Object
- #get_proxy_url ⇒ Object
- #get_retry_config ⇒ Object
- #get_sdk_key ⇒ Object
- #get_segmentation ⇒ Object
- #get_settings ⇒ Object
- #get_should_wait_for_tracking_calls ⇒ Object
- #get_storage ⇒ Object
- #get_vwo_builder ⇒ Object
- #get_vwo_meta ⇒ Object
-
#initialize(options = {}) ⇒ VWOOptionsModel
constructor
A new instance of VWOOptionsModel.
-
#model_from_dictionary(options) ⇒ Object
Creates a model instance from a hash (dictionary).
Constructor Details
#initialize(options = {}) ⇒ VWOOptionsModel
Returns a new instance of VWOOptionsModel.
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/wingify/models/vwo_options_model.rb', line 21 def initialize( = {}) @account_id = [:account_id] @sdk_key = [:sdk_key] @is_development_mode = [:is_development_mode] @storage = [:storage] @gateway_service = [:gateway_service] @poll_interval = [:poll_interval] @logger = [:logger] @segmentation = [:segmentation] @integrations = [:integrations] @network = [:network] @should_wait_for_tracking_calls = [:should_wait_for_tracking_calls] @settings = [:settings] @vwo_builder = [:vwo_builder] @is_usage_stats_disabled = [:is_usage_stats_disabled] @_vwo_meta = [:_vwo_meta] @retry_config = [:retry_config] @proxy_url = [:proxy_url] end |
Instance Attribute Details
#_vwo_meta ⇒ Object
Returns the value of attribute _vwo_meta.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def @_vwo_meta end |
#account_id ⇒ Object
Returns the value of attribute account_id.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def account_id @account_id end |
#gateway_service ⇒ Object
Returns the value of attribute gateway_service.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def gateway_service @gateway_service end |
#integrations ⇒ Object
Returns the value of attribute integrations.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def integrations @integrations end |
#is_development_mode ⇒ Object
Returns the value of attribute is_development_mode.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def is_development_mode @is_development_mode end |
#is_usage_stats_disabled ⇒ Object
Returns the value of attribute is_usage_stats_disabled.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def is_usage_stats_disabled @is_usage_stats_disabled end |
#logger ⇒ Object
Returns the value of attribute logger.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def logger @logger end |
#network ⇒ Object
Returns the value of attribute network.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def network @network end |
#poll_interval ⇒ Object
Returns the value of attribute poll_interval.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def poll_interval @poll_interval end |
#proxy_url ⇒ Object
Returns the value of attribute proxy_url.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def proxy_url @proxy_url end |
#retry_config ⇒ Object
Returns the value of attribute retry_config.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def retry_config @retry_config end |
#sdk_key ⇒ Object
Returns the value of attribute sdk_key.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def sdk_key @sdk_key end |
#segmentation ⇒ Object
Returns the value of attribute segmentation.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def segmentation @segmentation end |
#settings ⇒ Object
Returns the value of attribute settings.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def settings @settings end |
#should_wait_for_tracking_calls ⇒ Object
Returns the value of attribute should_wait_for_tracking_calls.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def should_wait_for_tracking_calls @should_wait_for_tracking_calls end |
#storage ⇒ Object
Returns the value of attribute storage.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def storage @storage end |
#vwo_builder ⇒ Object
Returns the value of attribute vwo_builder.
16 17 18 |
# File 'lib/wingify/models/vwo_options_model.rb', line 16 def vwo_builder @vwo_builder end |
Instance Method Details
#get_account_id ⇒ Object
62 63 64 |
# File 'lib/wingify/models/vwo_options_model.rb', line 62 def get_account_id @account_id end |
#get_gateway_service ⇒ Object
78 79 80 |
# File 'lib/wingify/models/vwo_options_model.rb', line 78 def get_gateway_service @gateway_service end |
#get_integrations ⇒ Object
94 95 96 |
# File 'lib/wingify/models/vwo_options_model.rb', line 94 def get_integrations @integrations end |
#get_is_development_mode ⇒ Object
70 71 72 |
# File 'lib/wingify/models/vwo_options_model.rb', line 70 def get_is_development_mode @is_development_mode end |
#get_is_usage_stats_disabled ⇒ Object
114 115 116 |
# File 'lib/wingify/models/vwo_options_model.rb', line 114 def get_is_usage_stats_disabled @is_usage_stats_disabled end |
#get_logger ⇒ Object
86 87 88 |
# File 'lib/wingify/models/vwo_options_model.rb', line 86 def get_logger @logger end |
#get_network ⇒ Object
98 99 100 |
# File 'lib/wingify/models/vwo_options_model.rb', line 98 def get_network @network end |
#get_poll_interval ⇒ Object
82 83 84 |
# File 'lib/wingify/models/vwo_options_model.rb', line 82 def get_poll_interval @poll_interval end |
#get_proxy_url ⇒ Object
126 127 128 |
# File 'lib/wingify/models/vwo_options_model.rb', line 126 def get_proxy_url @proxy_url end |
#get_retry_config ⇒ Object
122 123 124 |
# File 'lib/wingify/models/vwo_options_model.rb', line 122 def get_retry_config @retry_config end |
#get_sdk_key ⇒ Object
66 67 68 |
# File 'lib/wingify/models/vwo_options_model.rb', line 66 def get_sdk_key @sdk_key end |
#get_segmentation ⇒ Object
90 91 92 |
# File 'lib/wingify/models/vwo_options_model.rb', line 90 def get_segmentation @segmentation end |
#get_settings ⇒ Object
106 107 108 |
# File 'lib/wingify/models/vwo_options_model.rb', line 106 def get_settings @settings end |
#get_should_wait_for_tracking_calls ⇒ Object
102 103 104 |
# File 'lib/wingify/models/vwo_options_model.rb', line 102 def get_should_wait_for_tracking_calls @should_wait_for_tracking_calls end |
#get_storage ⇒ Object
74 75 76 |
# File 'lib/wingify/models/vwo_options_model.rb', line 74 def get_storage @storage end |
#get_vwo_builder ⇒ Object
110 111 112 |
# File 'lib/wingify/models/vwo_options_model.rb', line 110 def get_vwo_builder @vwo_builder end |
#get_vwo_meta ⇒ Object
118 119 120 |
# File 'lib/wingify/models/vwo_options_model.rb', line 118 def @_vwo_meta end |
#model_from_dictionary(options) ⇒ Object
Creates a model instance from a hash (dictionary)
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/wingify/models/vwo_options_model.rb', line 42 def model_from_dictionary() @account_id = [:account_id] @sdk_key = [:sdk_key] @vwo_builder = [:vwo_builder] @should_wait_for_tracking_calls = [:should_wait_for_tracking_calls] if .key?(:should_wait_for_tracking_calls) @is_development_mode = [:is_development_mode] if .key?(:is_development_mode) @storage = [:storage] if .key?(:storage) @gateway_service = [:gateway_service] if .key?(:gateway_service) @poll_interval = [:poll_interval] if .key?(:poll_interval) @logger = [:logger] if .key?(:logger) @segmentation = [:segmentation] if .key?(:segmentation) @integrations = [:integrations] if .key?(:integrations) @network = [:network] if .key?(:network) @settings = [:settings] if .key?(:settings) @retry_config = [:retry_config] if .key?(:retry_config) @proxy_url = [:proxy_url] if .key?(:proxy_url) self end |