Class: SampledDebugErrorTemplateKeys
- Inherits:
-
Object
- Object
- SampledDebugErrorTemplateKeys
- Defined in:
- lib/wingify/constants/sampled_debug_error_template_keys.rb
Overview
Debug error template keys (msg_t) that are subject to sampling. Keys not listed here always send and bypass sampling.
Constant Summary collapse
- SAMPLED_KEYS =
%w[ EVENT_NOT_FOUND FEATURE_NOT_FOUND FEATURE_NOT_FOUND_WITH_ID ].freeze
Class Method Summary collapse
-
.contains?(message_template_key) ⇒ Boolean
Checks whether a debug error template key should be sampled before sending.
Class Method Details
.contains?(message_template_key) ⇒ Boolean
Checks whether a debug error template key should be sampled before sending.
28 29 30 |
# File 'lib/wingify/constants/sampled_debug_error_template_keys.rb', line 28 def self.contains?() !.nil? && SAMPLED_KEYS.include?() end |